<?php
/**
* This function converts the weight unit.
*
* @internal
*
* @return string
*/
function JooviiAuspost_getWeight ($weight, $pickupCountry ) {
	$wpWeightUnit = get_option('woocommerce_weight_unit');
	$jooviiAuspostWeightUnit = 'kg';
	if ('AU' == $pickupCountry) {
		$jooviiAuspostWeightUnit = 'kg';
	}
	if ( 'US' == $pickupCountry ) {
		$jooviiAuspostWeightUnit = 'lbs';
	}
	if ( 'CA' == $pickupCountry) {
		$jooviiAuspostWeightUnit = 'kg';
	}
	if ($weight > 0) {
		$finalWeight= wc_get_weight( $weight, $jooviiAuspostWeightUnit, $wpWeightUnit );
	} else {
		$finalWeight = 0;
	}
	return round($finalWeight, 2);
}

/**
* This function converts the Dimension unit.
*
* @internal
*
* @return string
*/
function JooviiAuspost_getDimension ($dimension, $pickupCountry ) {
	$wpDimensionUnit = get_option('woocommerce_dimension_unit');
	//JooviiAuspost_logActions(" wpDimensionUnit :: ". $wpDimensionUnit );
	$jooviiAuspostDimensionUnit = 'm';
	if ( 'AU' == $pickupCountry) {
		$jooviiAuspostDimensionUnit = 'm';
	}
	if ('US' == $pickupCountry) {
		$jooviiAuspostDimensionUnit = 'in';
	}
	if ( 'CA' == $pickupCountry) {
		$jooviiAuspostDimensionUnit = 'm';
	}
	if ($dimension > 0) {
		$finalDimension =  wc_get_dimension( $dimension, $jooviiAuspostDimensionUnit, $wpDimensionUnit );
	} else {
		$finalDimension = 0;
	}
	//JooviiAuspost_logActions(" finalDimension :: ". $finalDimension );
	return $finalDimension;
}

/**
* This function returns Auspost's maxWeightLimit.
*
* @internal
*
* @return string
*/
function JooviiAuspost_maxWeightLimit ($pickupCountry, $deliveryCountry ) {
	$maxWeight = JOOVIIAUSPOST_AU_MAX_DOMESTIC_WEIGHT;
	if ('AU' == $pickupCountry) {
		$maxWeight = JOOVIIAUSPOST_AU_MAX_DOMESTIC_WEIGHT;
		if (  'AU' != $deliveryCountry) {
			$maxWeight = JOOVIIAUSPOST_AU_MAX_INTERNATION_WEIGHT;
		}
	}
	if ( 'US' == $pickupCountry ) {
		$maxWeight = JOOVIIAUSPOST_US_MAX_DOMESTIC_WEIGHT;
	}
	if ( 'CA' == $pickupCountry ) {
		$maxWeight = JOOVIIAUSPOST_CA_MAX_DOMESTIC_WEIGHT;
	}
	return $maxWeight;
}

/**
* This function returns AusPost's maxVolumeLimit.
*
* @internal
*
* @return string
*/
function JooviiAuspost_maxVolumeLimit ($pickupCountry, $deliveryCountry ) {
	$maxVolume = JOOVIIAUSPOST_AU_MAX_DOMESTIC_VOLUMN;
	if ( 'AU' == $pickupCountry) {
		$maxVolume = JOOVIIAUSPOST_AU_MAX_DOMESTIC_VOLUMN;
		if ( 'AU' != $deliveryCountry) {
			$maxVolume = JOOVIIAUSPOST_AU_MAX_INTERNATION_VOLUMN;
		}
	}
	if ( 'US' == $pickupCountry) {
		$maxVolume = JOOVIIAUSPOST_US_MAX_DOMESTIC_VOLUMN;
	}
	if ( 'CA' == $pickupCountry) {
		$maxVolume = JOOVIIAUSPOST_CS_MAX_DOMESTIC_VOLUMN;
	}
	return $maxVolume;
}

/**
* This function returns Auspost's RateArray.
*
* @internal
*
* @return array
*/
function JooviiAuspost_createRateArray ($package, $jooviiAuspost_setting, $result ) {
	
	JooviiAuspost_logActions(' JooviiAuspost_createRateArray function called ');

	$pickup_country = $jooviiAuspost_setting['pickup_country'];
	$shipping_quote_markup = 0;
	$shipping_handling_fee = 0;

	$jooviiAuspostcost=0;
	if (isset($result[0])) {
		$jooviiAuspostcost = $result[0]['quote']['gross']['amount'];
	}
	// Tax calculation start
	$taxesArray = '';
	$shipping_handling_fee_tax = 0;
	$shipping_handling_fee_net = 0;

	if ( 'AU' == $pickup_country) {
		$taxEnabled= get_option('woocommerce_calc_taxes');
		$taxClassExists = WC_Tax::get_rates();
		//print_r($taxClassExists);
		$calculatetax =1;
		if ( !empty($taxClassExists) && $calculatetax == 1 ) {
			JooviiAuspost_logActions(' taxClassExists :: ' . print_r($taxClassExists, true) . ' ');
			if ( 'yes' == $taxEnabled) {
				JooviiAuspost_logActions(' shipping TAX applied ');
				if (isset($result[0])) {
					$jooviiAuspostcost = $result[0]['quote']['net']['amount'];
				}
				$shipping_handling_fee_add = $shipping_handling_fee_net;
				$ratex = WC_Tax::_get_tax_rate('111');
				if ( !empty($ratex) ) {
					$tax_rate_id = $ratex['tax_rate_id'];
				} else {
					$taxkey =array_keys($taxClassExists);
					$taxClasspriority = WC_Tax::_get_tax_rate($taxkey['0']);
					$taxesArray1 = array(
						'tax_rate_id' => '111',
						'tax_rate_country' => '',
						'tax_rate_state' => '',
						'tax_rate' => 0,
						'tax_rate_name' => 'ShippingTax',
						'tax_rate_priority' => ( $taxClasspriority['tax_rate_priority'] + 1 ),
						'tax_rate_compound' => 0,
						'tax_rate_shipping' => 1,
						'tax_rate_order' => 1,
						'tax_rate_class' => '',
					);
					$tax_rate_id = WC_Tax::_insert_tax_rate( $taxesArray1 );
				}
				$taxesArray = array($tax_rate_id => $result[0]['quote']['tax']['amount'] + $shipping_handling_fee_tax);
				JooviiAuspost_logActions('  Final tax(AuspostTax + handling_fee_tax)  : ' . $result[0]['quote']['tax']['amount'] . ' + ' . $shipping_handling_fee_tax);
			} else {
				$taxesArray = false;
				if (isset($result[0])) {
					$jooviiAuspostcost = $result[0]['quote']['gross']['amount'];
				}
				$shipping_handling_fee_add = $shipping_handling_fee;
				JooviiAuspost_logActions('  shipping TAX --->NOT<---- applied [for taxEnabled = no] ');
			}
		} else {
			$taxesArray = false;
			if (isset($result[0])) {
				$jooviiAuspostcost = $result[0]['quote']['gross']['amount'];
			}
			$shipping_handling_fee_add = $shipping_handling_fee;
			JooviiAuspost_logActions('  shipping TAX --->NOT<---- applied [for taxClassExists = no] ');
		}
	} else {
		$taxesArray = false;
		if (isset($result[0])) {
			$jooviiAuspostcost = $result[0]['quote']['gross']['amount'];
		}
		$shipping_handling_fee_add = $shipping_handling_fee;
		JooviiAuspost_logActions('  shipping TAX --->NOT<---- applied [for US]');
	}
	// Tax calculation end
	JooviiAuspost_logActions('  Final cost without tax(auspostcost + handling_fee + markup)  : ' . $jooviiAuspostcost . ' + ' . $shipping_handling_fee_add . ' + ' . ( $jooviiAuspostcost * $shipping_quote_markup/100 ) );
	
	$plan_name=str_replace(' ', '-',strtolower($result[0]['plan_name']));
	
	$rate = array(  
	   'id' => 'jooviiauspost-zone-' . $plan_name,
	   'label'=> $result[0]['plan_name'],
	   'cost'=>  ( $jooviiAuspostcost + $shipping_handling_fee_add + ( $jooviiAuspostcost * $shipping_quote_markup/100 ) ),
	   'taxes'=> $taxesArray,
	   'calc_tax'=> 'per_order' 
	);
	
	if ( 0 == $rate['cost'] ) {
		return;
	}
	//JooviiAuspost_logActions(" result :: ".print_r($result,true)." ");
	JooviiAuspost_logActions(' JooviiAuspost_createRateArray function ended :: Rate -> ' . print_r($rate, true) . ' ');
	return $rate;
}

/**
* This function returns AusPost's DownloadLabelLink.
*
* @internal
*
* @return array
*/
function JooviiAuspost_getDownloadLabelLink($jooviiAuspost_order_id) {
	return true;
}
