<?php
/**
* Plugin Name: Joovii Auspost Shipping
* Plugin URI: https://joovii.com/australia-post/
* Description: This app provides the ultimate connectivity between Shopify and Auspost.
* Version: 1.1.1
* Author: Joovii
* Author URI: http://joovii.com/installation-instruction/wp
* License: GPLv2
* License URI: http://www.gnu.org/licenses/gpl-3.0.html
* Domain Path: /
* Text Domain: joovii-auspost-shipping-method
* WC requires at least: 3.0
* WC tested up to: 9.2.3
* Stable tag: 1.1.1
*/
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	define( 'JOOVIIAUSPOST_AU_MAX_DOMESTIC_WEIGHT', '25' );
	define( 'JOOVIIAUSPOST_AU_MAX_INTERNATION_WEIGHT', '20' );
	define( 'JOOVIIAUSPOST_US_MAX_DOMESTIC_WEIGHT', '70' );
	define( 'JOOVIIAUSPOST_CA_MAX_DOMESTIC_WEIGHT', '25' );
	define( 'JOOVIIAUSPOST_AU_MAX_DOMESTIC_VOLUMN', '0.100001' );
	define( 'JOOVIIAUSPOST_AU_MAX_INTERNATION_VOLUMN', '0.125' );
	define( 'JOOVIIAUSPOST_US_MAX_DOMESTIC_VOLUMN', '864' );
	define( 'JOOVIIAUSPOST_CS_MAX_DOMESTIC_VOLUMN', '0.125' );
	define( 'JOOVIIAUSPOST_WP_JAUSPOST_PLUGIN_VERSION', '1.1.1' );
	define('JOOVIIAUSPOST_WEBAPP_URL', 'https://webapp.joovii.com');

	$countries = ['CA' => 'Canada','AU' => 'Australia','US' => 'United States','NZ' => 'New Zealand'];
	add_action( 'before_woocommerce_init', function() {
		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	} );

	add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'JooviiAuspost_add_plugin_page_settings_link');
	add_action( 'woocommerce_shipping_init', 'JooviiAuspost_Shipping_Method' );
	add_filter( 'woocommerce_shipping_methods', 'JooviiAuspost_add_shipping_method' );

	add_action('admin_menu', 'JooviiAuspost_settings');
	add_action('admin_menu', 'JooviiAuspost_trackingemailtemplate_menu');
	require_once('joovii-auspost-shipping-function.php');
	require_once('joovii-auspost-shipping-zone.php');
	require_once('joovii-auspost-loader.php');
	require_once('joovii-auspost-logs.php');
	require_once('joovii-auspost-admin-feature.php');
	require_once('joovii-auspost-tracking-email.php');
    require_once('orders.php');
	require_once('order.php');
	require_once('apiresponse.php');
	require_once('subscribesuccess.php');
	require_once('shipment-update.php');
	
	$jooviiAuspost_setting = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
	//$book_shipment_on = $jooviiAuspost_setting['book_shipment_on'];
	//if ( 'order_submit' == $book_shipment_on){
	add_action('woocommerce_thankyou', 'JooviiAuspost_generate_reference', 111, 1);
	//}
	
	// REST API ENDPOINTS -- get all orderd orders.php
	add_action( 'rest_api_init', function () {
		register_rest_route( 'joovii/auspostwoocom/v1', '/orders', array(
			'methods' => 'GET',
			'callback' => 'jooviiauspost_get_all_orders',
		) );
	} );

	// REST API ENDPOINTS -- get a particular order order.php
	add_action( 'rest_api_init', function () {
		register_rest_route( 'joovii/auspostwoocom/v1', '/order', array(
			'methods' => 'GET',
			'callback' => 'jooviiauspost_get_order',
		) );
	} );
	
	// REST API ENDPOINTS -- update settings -- apiresponse.php
	add_action( 'rest_api_init', function () {
		register_rest_route( 'joovii/auspostwoocom/v1', '/updateSettings', array(
			'methods' => 'GET',
			'callback' => 'jooviiauspost_update_settings',
		) );
	} );
	
	// REST API ENDPOINTS -- update Subscriber Success -- subscribesuccess.php
	add_action( 'rest_api_init', function () {
		register_rest_route( 'joovii/auspostwoocom/v1', '/subscribesuccess', array(
			'methods' => 'GET',
			'callback' => 'jooviiauspost_subscribe_success',
		) );
	} );
	
	// REST API ENDPOINTS -- update Shipment Details -- shipment-update.php
	add_action( 'rest_api_init', function () {
		register_rest_route( 'joovii/auspostwoocom/v1', '/shipmentupdate', array(
			'methods' => 'GET',
			'callback' => 'jooviiauspost_shipment_update',
		) );
	} );
	
} 
// IF ENDS

/**
* This function shows Error messages
* as API response and ends the execution
*
* @param String $msg : Input Message
*
* @return void
*/
function JooviiAuspost_return($msg) {
	return wp_json_encode(['err' => 1, 'msg' => $msg]);
}

/**
 * This function Returns Message
 *
 * @param  Integer $err
 *
 * @param  String $msg
 *
 * @return void
 */
function JooviiAuspost_retMsg($err, $msg) {
	echo wp_json_encode(['err' => $err, 'msg' => $msg]);
	die();
}

// CHECK if HPOS is enabled
function JooviiAuspost_check_if_hpos_enabled()
{
	$hpos_enabled = 0;

	if (class_exists(\Automattic\WooCommerce\Utilities\OrderUtil::class) ) {
		if (\Automattic\WooCommerce\Utilities\OrderUtil::custom_orders_table_usage_is_enabled() ) {
			$hpos_enabled  = 1;
		}
	}
	
	return $hpos_enabled;
}

function JooviiAuspost_generate_reference($order_id=0, $postedby='byfn') {

	$jooviiAuspost_setting = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
	$book_shipment_on = $jooviiAuspost_setting['book_shipment_on'];
	JooviiAuspost_logActions('----------- ' . $book_shipment_on . '------- ' . $postedby . '------- ' . $order_id . '------------------------/n');
	JooviiAuspost_logActions('jooviiAuspost_setting array :: ' . print_r($jooviiAuspost_setting, true) );

	$putarray = ['orderid'=>$order_id, 'shopid'=>$jooviiAuspost_setting['shop_id'], 'securitycode'=>$jooviiAuspost_setting['accesstoken'], 'order_onsubmit'=>'yes', 'bookshipment'=>'yes'];
	$securitycode = isset($st['accesstoken']) ? $st['accesstoken'] : '';
	JooviiAuspost_logActions('Before Save-order CALL 1 :: ' . JOOVIIAUSPOST_WEBAPP_URL . '/shopadmin/woocom/sync/order/update?orderid=' . $order_id );
	JooviiAuspost_logActions('Before Save-order CALL 2 :: ' . print_r( $putarray , true) );
	$ret = JooviiAuspost_makeapicall( '/shopadmin/woocom/sync/order/update?orderid=' . $order_id, $putarray ) ;
	JooviiAuspost_logActions('After Save-order CALL 1 :: ' . $order_id );
	JooviiAuspost_logActions('After Save-order CALL 2 :: ' . print_r($ret, true) );

}


// Separate SYNC Function 
function JooviiAuspost_webapp_sync_store_standalone() {
	JooviiAuspost_logActions('Sync Started');
	$all_options = wp_load_alloptions();
	$allopt = maybe_unserialize($all_options['woocommerce_jooviiauspost_settings']);
	
	$set = [];
	
	$st = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
	$id = '';
	$key = '';
	$mode = '';
	if ( is_array($st) ) {
		if (isset($st['api_id']) && '' != trim($st['api_id']) && isset($st['api_key']) && '' != trim($st['api_key'])  && isset($st['mode']) && '' != trim($st['mode'])) {
			$id = $st['api_id'];
			$key = $st['api_key'];
			$mode = $st['mode'];
		}
	}

	$id = 'jooviiauspost_api_id';
	$key = 'jooviiauspost_api_key';

	$set = ['api_id' => $id, 'api_key' => $key, 'mode' => $mode];
	
	if ( '' != $set['api_id']   ) {
		$set['site_url'] = get_option('siteurl');
		$set['id'] = uniqid();
		$set['name'] = get_option('blogname');
		$set['email'] = get_option('admin_email');
		$set['domain'] = ( isset ($_SERVER['REMOTE_ADDR']) ? sanitize_text_field( wp_unslash($_SERVER['REMOTE_ADDR'])) : '' );
		$d = get_option('woocommerce_default_country');
		$province = $d;
		$country  = $d;
		if ( '' != $d) {
			$t = explode(':', $d);
			if (count($t) == 2) {
				$country  = $t[0];
				$province = $t[1];
			}
		}
		$set['province']  = $province;
		$set['country']   = $country;
		$set['address1']  = trim(get_option('woocommerce_store_address'));
		$set['address2']  = trim(get_option('woocommerce_store_address_2'));
		$set['zip']       = get_option('woocommerce_store_postcode');
		$set['city']      = get_option('woocommerce_store_city');
		$set['source']    = '';
		$set['phone']     = '';
		$set['latitude']  = '';
		$set['longitude'] = '';
		$set['primary_locale'] = 'en';
		//$set['created_at']   = '';
		//$set['updated_at']   = '';
		$set['country_code'] = $country;
		$set['country_name'] = get_option('woocommerce_default_country');
		$set['currency']     = get_option('woocommerce_currency');
		$set['customer_email'] = get_option('admin_email');
		$set['timezone'] = '';
		$set['iana_timezone'] = '';
		$set['shop_owner']   = '';
		$admin_user = get_user_by( 'email', $set['email']);

		if ( '' == $allopt['sender_name']) {
			if ( $admin_user ) {
				$first_name = get_user_meta($admin_user->ID, 'first_name', true);
				$last_name  = get_user_meta($admin_user->ID, 'last_name', true);
				if ( '' == $first_name . $last_name) {
					$set['shop_owner'] = get_option('blogname');
				} else {
					$set['shop_owner'] = $first_name . ' ' . $last_name;
				}
			}
		} else {
			$set['shop_owner'] = $allopt['sender_name'];
		}
		$set['money_format'] = $set['currency'] . '{{amount}}';
		$set['money_with_currency_format']='${{amount}} ' . $set['currency'];
		$set['weight_unit'] = get_option('woocommerce_weight_unit');
		$set['dimension_unit'] = get_option('woocommerce_dimension_unit');
		$set['province_code'] = $province;
		$set['taxes_included']='';
		$set['auto_configure_tax_inclusivity']='';
		$set['tax_shipping']='';
		$set['county_taxes'] = '1';
		$set['plan_display_name'] = '';
		$set['plan_name']  = '';
		$set['has_discounts']='';
		$set['has_gift_cards']='';
		$set['myshopify_domain']='';
		$set['google_apps_domain']='';
		$set['google_apps_login_enabled']='';
		$set['money_in_emails_format']= $set['currency'] . '{{amount}}';
		$set['money_with_currency_in_emails_format']='${{amount}} ' . $set['currency'];
		$set['eligible_for_payments'] = '1';
		$set['requires_extra_payments_agreement']='';
		$set['password_enabled']='';
		$set['has_storefront']='';
		$set['finances']='1';
		$set['primary_location_id']='';
		$set['checkout_api_supported']='';
		$set['multi_location_enabled']='';
		$set['setup_required']='';
		$set['pre_launch_enabled']='';
		$set['transactional_sms_disabled']='';
		$set['marketing_sms_consent_enabled_at_checkout']='';
		$set['pickup_country'] = get_option('woocommerce_jooviiauspost_pickup_country');
		// New ADDITION
		//$set['enabled']     = $allopt['enabled'];
		//$set['showrates']   = $allopt['showrates'];
		$set['pickup_suburb'] = $allopt['pickup_suburb'];
		$set['pickup_postcode'] = $allopt['pickup_postcode'];
		$set['pickup_country'] = $allopt['pickup_country'];
		//$set['quote_markup'] = $allopt['quote_markup'];
		//$set['shipping_handling_fee'] = $allopt['shipping_handling_fee'];
		$set['enable_addressmatch'] = $allopt['enable_addressmatch'];
		$set['volume_param'] = isset($allopt['volume_param']) ? $allopt['volume_param'] : '';
		$set['warningtext_enable'] = isset($allopt['warningtext_enable'])?$allopt['warningtext_enable']:'';
		$set['warningtext'] = isset($allopt['warningtext'])?$allopt['warningtext']:'';
		//$set['pickupoption']=$allopt['pickupoption'];
		//$set['book_shipment_on']= $allopt['book_shipment_on'];
		//$set['sender_name']=$allopt['sender_name'];
		$set['sender_contact_number'] = $allopt['sender_contact_number'];
		$set['sender_address'] = trim($set['address1'] . ' ' . $set['address2']);
		$set['sender_state'] = $allopt['sender_state'];
		//$set['sender_instruction']=$allopt['sender_instruction'];
		//$set['receiver_instruction']=$allopt['receiver_instruction'];
		//$set['pickup_delay']=$allopt['pickup_delay'];
		$set['change_order_status'] = $allopt['change_order_status'];
		$set['tracking_email']=$allopt['tracking_email'];
		//$set['hs_code']=$allopt['hs_code'];
		//$set['hs_code_field_name']=$allopt['hs_code_field_name'];
		$set['optintojoovii']=$allopt['optintojoovii'];
		//$set['contents_type']=$allopt['contents_type'];
		$set['enable_log']=$allopt['enable_log'];
		//$set['packaging_weight_cart']=$allopt['packaging_weight_cart'];
		//$set['hide_pickup_address']=$allopt['hide_pickup_address'];
		//$set['customer_reference'] = $allopt['enable_customer_reference'];

		JooviiAuspost_logActions('Before Save-Settings CALL :: ' . print_r($set, true) );
		$ret = JooviiAuspost_makeapicall('/woocom/jooviiauspost/sync/store/savesettings', $set) ;
		JooviiAuspost_logActions('After Save-Settings CALL :: ' . print_r($ret, true) );
		$temp = json_decode($ret, true);
		if ( is_array($temp) ) {
			if ( isset($temp['shop_id']) && '' != $temp['shop_id'] && isset($temp['accesstoken']) && '' != $temp['accesstoken']	) {
				$data = [];
				if ( isset($temp['shop_id']) && '' != $temp['shop_id'] ) {
					$data['shop_id'] = $temp['shop_id'];
				}

				if ( isset($temp['accesstoken']) && '' != $temp['accesstoken'] ) {
					$data['accesstoken'] = $temp['accesstoken'];
				}

				if ( count($data) ) {
					// UPDATE Options
					foreach ($data as $key => $val) {
						if ( '' != $key) {
							if ( 'accesstoken' == $key  ||  'shop_id' == $key ) {
								$st[$key] = $val;
							}
						}
					}
					JooviiAuspost_logActions('Updated shopid and accesstoken in Settings');
					update_option('woocommerce_jooviiauspost_settings', $st);
				}
			}
			add_action('admin_notices', function() use ( $temp ) {
				if ( is_array($temp) ) {
					if ( isset($temp['err']) && isset($temp['msg']) ) {
						$class = $temp['err'] ? 'error' : 'updated';
						echo '<div class="notice $class"><p>' . esc_html($temp['msg']) . '</p></div>';
					}
				}
			});
		} else {
			add_action('admin_notices', function() use ( $temp ) {
				echo '<div class="notice error"><p>Credential Validation Failed</p></div>';
			} );
		}
	} else {
		JooviiAuspost_logActions('SaveSettings Error .. Params Missing');
	}
}

/**
* This function creates webhook for order created and updated.
*
* @internal
*
* @return object
*/
function JooviiAuspost_webhook_plugin_activated() {
	
	// SYNC the shop 
	$userID='1';
	$topic='order.created';
	$userName='JooviiOrderCreated';
	$secret=wp_generate_password(50, true, true);
	$jooviiAuspost_setting = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );

	$deliveryURL= JOOVIIAUSPOST_WEBAPP_URL . '/shopadmin/woocom/sync/order/webhookcall?callname=jooviiordercreated&shopid=' . $jooviiAuspost_setting['shop_id'] . '&securitycode=' . $jooviiAuspost_setting['accesstoken'];
	$status='active';
	$webhook = new WC_Webhook();
	$webhook->set_user_id($userID); // User ID used while generating the webhook payload.
	$webhook->set_name($userName);
	$webhook->set_topic($topic); // Event used to trigger a webhook.
	$webhook->set_secret($secret); // Secret to validate webhook when received.
	$webhook->set_delivery_url($deliveryURL); // URL where webhook should be sent.
	$webhook->set_status($status); // Webhook status.
	$save = $webhook->save();
	JooviiAuspost_logActions('JooviiAuspost_webhook_plugin_activated CALL  :: '  );
	
	JooviiAuspost_webapp_sync_store_standalone();
	return $save;

}

register_activation_hook(__FILE__, 'JooviiAuspost_create_logs_table');
register_activation_hook(__FILE__, 'JooviiAuspost_webhook_plugin_activated');

/**
* This function creates a new table to store log data.
*
* @internal
*
* @return boolean
*/
function JooviiAuspost_create_logs_table() {
	global $wpdb;
	$table_name = $wpdb->prefix . 'jooviiauspost_logs';
	$charset_collate = $wpdb->get_charset_collate();
	$sql = "CREATE TABLE IF NOT EXISTS $table_name (
		`id` int(11) NOT NULL AUTO_INCREMENT,
		`eventname` varchar(50) CHARACTER SET utf8 NOT NULL,
		`orderid` int(11) NOT NULL,
		`logs` text CHARACTER SET utf8 NOT NULL,
		`timestamp` varchar(50) CHARACTER SET utf8 NOT NULL,
		PRIMARY KEY (`id`)
	)" . $charset_collate . '; ';
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta($sql);
	return true;
}

/**
* This function adds "Auspost Settings" submenu  in leftmenu .
*
* @internal
*
* @return boolean
*/
function JooviiAuspost_settings() {
	add_submenu_page( 'woocommerce', 'Joovii Auspost Settings', 'Joovii Auspost Settings', JooviiAuspost_getAssignRole(), 'admin.php?page=wc-settings&tab=shipping&section=jooviiauspost', null, 2 );
	return true;
}

/**
* This function adds "Auspost Email Template" submenu in leftmenu.
*
* @internal
*
* @return boolean
*/
function JooviiAuspost_trackingemailtemplate_menu() {
	/*
	add_submenu_page('woocommerce', 'Joovii Email Template', 'Joovii Email Template', JooviiAuspost_getAssignRole(), 'JooviiAuspost_trackingemailtemplate', 'JooviiAuspost_trackingemailtemplate', 4 );
	*/
	return true;
}



/**
* This function adds "Settings" link in plugin page.
*
* @internal
*
* @return array
*/
function JooviiAuspost_add_plugin_page_settings_link( $links ) {
	$links[] = '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=shipping&section=jooviiauspost' ) . '">' . __('Settings', 'joovii-auspost-shipping-method') . '</a>';
	return $links;
}

add_action('admin_menu', 'JooviiAuspost_goto_web_app');

/**
* This function adds "Go To Web App" link in left menu.
*
* @internal
*
* @return array
*/
function JooviiAuspost_goto_web_app() {
	add_submenu_page('woocommerce', 'Joovii Shipping App', 'Joovii Shipping App', JooviiAuspost_getAssignRole(), 'JooviiAuspost_goto_webapp_function', 'JooviiAuspost_goto_webapp_function', 3);
}

/**
* This function handles when a link is clicked.
*
* @internal
*
* @return void
*/
function JooviiAuspost_goto_webapp_function() {

	$st = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );

	$shop_id = isset($st['shop_id']) ? $st['shop_id'] : '';
	$host = get_option('siteurl');
	$securitycode = isset($st['accesstoken']) ? $st['accesstoken'] : '';

	$base_url   = JOOVIIAUSPOST_WEBAPP_URL ;
	
	$target_url =  $base_url . '/shopadmin/home?shopid=' . $shop_id . '&securitycode=' . $securitycode ;

	if ( '' == $shop_id || '' == $securitycode ) {
		echo '<span style="font-weight:bold;font-size:15px;">Shop ID or Security Code not found</span>';

	} else {
		/*
		echo '<a id="gotowebapp" href="' . esc_url($target_url) . '" target="_blank">Please Wait</a>
				scri pt
				var r = document.getElementById("gotowebapp");
				r.click();

				var timer = setTimeout(function (){
				   r.innerHTML = "Click Here to go back";
				   r.removeAttribute("target");
				   r.setAttribute("onclick", "window.history.go(-1);return false;");
				   r.setAttribute("href", "#");
				   clearTimeout(timer);
				},2000);
				scr ipt';
		*/
		
		 echo "<iframe src='". esc_url($target_url) . "' style='width:100%;height:800px;'></iframe>";
	}
}

/**
* This function creates "Settings" option in  admin for this plugin.
*
* @internal
*
* @return boolean
*/

function JooviiAuspost_Shipping_Method() {
	$assign_permission=JooviiAuspost_getAssignPermission();
	if ( ! class_exists( 'JooviiAuspost_Shipping_Method' )  && $assign_permission ) {
		class JooviiAuspost_Shipping_Method extends WC_Shipping_Method {
			/**
			* This is a construct function.
			*
			* @internal
			*
			* @return boolean
			*/
			public function __construct() {
				
				$_jset = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
				$subscribeHtml = '';
				
				
				if( is_array($_jset) && isset($_jset['shop_id']) && $_jset['shop_id']!='' && is_numeric($_jset['shop_id']) && 
					isset($_jset['accesstoken']) && $_jset['accesstoken']!='' )
				{
					
					
					/// Do a CURL call 
					$is_subscribed = 0;
					$subscription_expired = 1;
					
					$target_url = JOOVIIAUSPOST_WEBAPP_URL . "/shopadmin/settings/subscriptionstatus?shopid=" . $_jset['shop_id'] . "&securitycode=" . $_jset['accesstoken'] . "&product=auspost-wp";
					$args = [];
					//echo " [$target_url] ";
					$content = wp_remote_get($target_url);
					if ( is_wp_error( $content ) ) {
						$error_message = $content->get_error_message();
						JooviiAuspost_logActions('Something went wrong while fetching Subscription Status [wp_remote_post]:' . $error_message);
					} else {
						if(is_array($content) && isset($content['body']) && $content['body']!='') {
							$res = json_decode($content['body'], true);
							if(isset($res['is_subscribed']) && $res['is_subscribed'] == 1) {
								$is_subscribed = 1;
								if(isset($res['subscription']['subscribe_expiry_date'])) {
									$expiry_date = $res['subscription']['subscribe_expiry_date'];
									$today = gmdate("Y-m-d", time());
									if( $expiry_date >= $today )
									{
										$subscription_expired = 0;	
									}
								}
							}
						}
					}
					
					JooviiAuspost_logActions ("Subscription Status [$is_subscribed][$subscription_expired]");
					
					if( $is_subscribed == 0 || $subscription_expired == 1 )
					{
						$url = JOOVIIAUSPOST_WEBAPP_URL . '/shopadmin/settings/subscribe?securitycode=' . $_jset['accesstoken'] 
							   . "&shopid=" . $_jset['shop_id'] . "&product=auspost-wp";
						
						$subscribeHtml = "<div style='padding:12px;border:1px solid #ccc;'>
						Subscribe to get Auspost Rates at checkout and book Auspost Shipment Quickly from a single Dashboard.
						<a href='$url' target='_blank' title='Click to Subscribe' style='display:inline-block;'>Subscribe Now !!!</a> 
						</div>";
					}
					
					if( $is_subscribed == 1 && $subscription_expired == 0 )
					{
						
						$subscribeHtml = "<div style='padding:12px;border:1px solid #ccc;'>
						You have Subscribed to Joovii Auspost Shipments and Your Subscription renews on " . gmdate("d M, Y", strtotime($expiry_date)) . ".
						</div>";
					}

				}					
				
				$this->id                  = 'jooviiauspost';
				$this->method_title        = __( 'Joovii Auspost', 'joovii-auspost-shipping-method' );
				$this->method_description  = 'This app provides the ultimate connectivity between Shopify and Auspost.' . 
											 'By integrating Auspost with your woocom store, you get in cart shipping quotes, ' .  
											 'order confirmation, booking shipment, download shipping labels and easy tracking ' . 
											 'updates.' . $subscribeHtml;
				$this->availability 	   = 'jooviiauspost_wp';
				$this->init();
				$this->enabled = isset( $this->settings['enabled'] ) ? $this->settings['enabled'] : 'no';
				$this->title   = isset( $this->settings['title'] ) ? $this->settings['title'] : __( 'Joovii Auspost', 'joovii-auspost-shipping-method' );
			}
			/**
			* This is a init function.
			*
			* @internal
			*
			* @return boolean
			*/
			public function init() {
				$this->init_settings();
				$this->init_form_fields();
				add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
				add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'JooviiAuspost_webapp_sync_store' ) );
			}
			/**
			* This function generates settings html.
			*
			* @internal
			*
			* @return string
			*/
			public function generate_settings_html( $form_fields = array(), $echo = true ) {
				if ( empty( $form_fields ) ) {
					$form_fields = $this->get_form_fields();
				}
				$html_content = '';
				foreach ( $form_fields as $k => $v ) {
					$type = $this->get_field_type( $v );
					if ( 'JooviiAuspost_customplaceholder' == $type ) {
						$html_content .= $this->JooviiAuspost_generate_text_html_custom( $k, $v );
					} else {
						if ( method_exists( $this, 'generate_' . $type . '_html' ) ) {
							$html_content .= $this->{'generate_' . $type . '_html'}( $k, $v );
						} else {
							$html_content .= $this->generate_text_html( $k, $v );
						}
					}
				}
				if ( $echo ) {
					return $html_content ; // WPCS: XSS ok.
				} else {
					return $html_content ;
				}
			}
			/**
			* This function generates custom settings html.
			*
			* @internal
			*
			* @return string
			*/
			public function JooviiAuspost_generate_text_html_custom ( $key, $data ) {
				$defaults = array();
				$data = wp_parse_args( $data, $defaults );
				$html_content = '<tr valign="top">';
				$html_content .= '<td class="forminp" colspan="2">';
				$html_content .= '<br><br>--------------------------- ' . wp_kses_post( $data['title'] ) . '   ---------------------------------------------- <br><br>';
				$html_content .= '</td>';
				$html_content .= '</tr>';
				return $html_content;
			}
			/**
			* This function generates  settings .
			*
			* @internal
			*
			* @return string
			*/
			public function init_form_fields() {

				$city = get_option('woocommerce_store_city');
				$country = get_option('woocommerce_default_country');
				$postcode = get_option('woocommerce_store_postcode');
				$state = '';
				if ( '' != $country ) {
					$data = explode(':', $country);
					if (is_array($data) && count($data)) {
						$country = $data[0];
						$state   = $data[1];
					}
				}

				$address1 = trim(get_option('woocommerce_store_address'));
				$address2 = trim(get_option('woocommerce_store_address_2'));

				$sender_name = get_bloginfo( 'name' );
				$sender_phone = '';

				$current_user_id = get_current_user_id();
				$phone = get_user_meta($current_user_id, 'billing_phone', true);

				if ('' == $phone) {
				  $phone = get_user_meta($current_user_id, 'shipping_phone', true);
				}

				$sender_phone = $phone;

				$sender_address = trim( $address1 . ' ' . $address2 );

				$jooviiAuspost_setting = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
				$shop_id = isset($jooviiAuspost_setting['shop_id']) ? $jooviiAuspost_setting['shop_id'] : '';
				$securitycode = isset($jooviiAuspost_setting['accesstoken']) ? $jooviiAuspost_setting['accesstoken'] : '';

				$optionArray = array(

					'enable_log' => array(
						'title'       => 	__( 'Enable Log', 'joovii-auspost-shipping-method' ),
						'type'        => 	'checkbox',
						'description' => 	__( '<a href="admin.php?page=JooviiAuspost_logs">Check Logs</a>', 'joovii-auspost-shipping-method' ),
						'default'     => 	__( 'no', 'joovii-auspost-shipping-method' )
					),
					'enable_addressmatch' => array(
						'title'       => 	__( 'Enable Address Match', 'joovii-auspost-shipping-method' ),
						'type'        => 	'checkbox',
						'description' => 	__( 'Enable Address Match At Checkout', 'joovii-auspost-shipping-method' ),
						'default'     => 	__( 'yes', 'joovii-auspost-shipping-method' )
					)

				);
				// ----------------orderconfig_line---------------------------------------------------
				$order_address_manager_seperator_array =   array(
					'orderaddressconfig_line' => array(
						'title'       => 	__( 'Store Address Configuration', 'joovii-auspost-shipping-method' ),
						'type'        => 	'JooviiAuspost_customplaceholder',
						'description' => 	__( '[Do it here] ', 'joovii-auspost-shipping-method' )
					)
				);
				$optionArray = array_merge($optionArray, $order_address_manager_seperator_array);

				$order_address_manager_array =   array(

						'sender_name' => array(
							'title'       => __( 'Sender Name', 'joovii-auspost-shipping-method' ),
							'type'        => 'text',
							'description' => __( 'Sender Name', 'joovii-auspost-shipping-method' ),
							'default'       => $sender_name
						),

						'sender_contact_number' => array(
						   'title'       => 	__( 'Sender Contact Number', 'joovii-auspost-shipping-method' ),
						   'type'        => 	'text',
						   'description' => 	__( 'Used to coordinate pickup if the courier is outside attempting delivery.Must be a valid phone number. 13, 1300, and 1800 numbers are not allowed.', 'joovii-auspost-shipping-method' ),
						   'default'     => 	$sender_phone
						),

						'sender_address' => array(
						   'title'       => 	__( 'Sender Address', 'joovii-auspost-shipping-method' ),
						   'type'        => 	'text',
						   'description' => 	__( 'The street address where the parcel will be picked up.', 'joovii-auspost-shipping-method' ),
						   'default'     => 	$sender_address
						),

						'sender_state' => array(
						   'title'       => 	__( 'Sender State', 'joovii-auspost-shipping-method' ),
						   'type'        => 	'text',
						   'description' => 	__( 'Must be the pickup location’s state or territory.', 'joovii-auspost-shipping-method' ),
						   'default'     => 	$state
						),

						'pickup_suburb' => array(
						   'title'       => 	__( 'Pickup Suburb', 'joovii-auspost-shipping-method' ),
						   'type'        => 	'text',
						   'description' => 	__( 'Suburb must be real and match pickup postcode.', 'joovii-auspost-shipping-method' ),
						   'default'     => 	$city
						),

						'pickup_postcode'  => array(
						   'title'       => 	__( 'Pickup Postcode', 'joovii-auspost-shipping-method' ),
						   'type'        => 	'text',
						   'description' => 	__( 'Four-digit post code for the pickup address.', 'joovii-auspost-shipping-method' ),
						   'default'     => 	$postcode
						),

						'pickup_country' => array(
						   'title'       => __( 'Pickup Country', 'joovii-auspost-shipping-method' ),
						   'type'        => 'select',
						   'description' => __( 'Pickup Country', 'joovii-auspost-shipping-method' ),
						   'default'     => $country,
						   'options'     => array('US'=>'United States','CA'=>'Canada','AU'=>'Australia',''=>'Please Select'),
						),
				) ;
				$optionArray = array_merge($optionArray, $order_address_manager_array);
				// ----------------orderconfig_line---------------------------------------------------
				$order_manager_seperator_array =   array(
					'orderconfig_line' => array(
						'title'       => 	__( 'Order Synchronization Configuration', 'joovii-auspost-shipping-method' ),
						'type'        => 	'JooviiAuspost_customplaceholder',
						'description' => 	__( '[Do it here] ', 'joovii-auspost-shipping-method' )
					)
				) ;
				$optionArray = array_merge($optionArray, $order_manager_seperator_array);
				$order_manager_array =   array(
					
					'change_order_status' => array(
						'title'       => 	__( 'Change Order Status', 'joovii-auspost-shipping-method' ),
						'type'        => 	'select',
						'description' => 	__( 'Change Order Status to Processing/Completed after shipment booking', 'joovii-auspost-shipping-method' ),
						'default'     => 	'no',
						'options'     => 	array('processing'=>'Processing', 'completed'=>'Completed', 'no'=>'No'),
					),
					'tracking_email' => array(
						'title'         =>	__('Send Tracking Email', 'joovii-auspost-shipping-method'),
						'type'          =>	'checkbox',
						'description'   =>	__('Send Tracking Email. <a href="admin.php?page=JooviiAuspost_trackingemailtemplate">Edit Tracking Email Template.</a> ', 'joovii-auspost-shipping-method'),
						'default'       =>	__('no', 'joovii-auspost-shipping-method')
					)

				);
				$optionArray = array_merge($optionArray, $order_manager_array);
				// ----------------devconfig_line---------------------------------------------------
				$devconfig_manager_array =   array(
					'devconfig_line' => array(
						'title'       => 	__( 'Developer Configuration', 'joovii-auspost-shipping-method' ),
						'type'        => 	'JooviiAuspost_customplaceholder',
						'description' => 	__( '[Do it here] ', 'joovii-auspost-shipping-method' )
					),
					'optintojoovii' => array(
						'title'         =>	__('Allow access to Joovii API\'s.', 'joovii-auspost-shipping-method'),
						'type'          =>	'checkbox',
						'description'   =>	__('This is required to allow live shipping quoting and booking and for support from Joovii.   The plugin will be disabled without this access approved. ', 'joovii-auspost-shipping-method'),
						'default'       =>	__('yes', 'joovii-auspost-shipping-method')
					)

				);
				$optionArray = array_merge($optionArray, $devconfig_manager_array);
				$role_manager_array = [ 'role_manager' => ['title'  => __( 'User Role Manager', 'joovii-auspost-shipping-method' ), 'type' => 'select', 'description' => __( 'Which user role can access this plugin', 'joovii-auspost-shipping-method' ), 'default' => 'None', 'options' => ['None'=>'None', 'shop_manager'=>'Shop manager' ] ] ];
				if (JooviiAuspost_getAssignRole() == 'administrator') {
					$optionArray = array_merge($optionArray, $role_manager_array);
				}

				$this->form_fields = $optionArray;
			}
			
			public function calculate_shipping( $package = array() ) {

                //$result = ossm_calculateSendleRate($package );
                //if(!is_array($result)){ reurn; }else{ $this->add_rate( $result ); }
                $auspost_setting = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
                //ossm_checkSendleZone($auspost_setting);
			}
			
			/**
			* This is a copy function returns existing settings.
			*
			* @internal
			*
			* @return string
			*/
			public function JooviiAuspost_get_existing_settings() {
				$st = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
				$id = '';
				$key = '';
				$mode = '';
				if ( is_array($st) ) {
					if (isset($st['api_id']) && '' != trim($st['api_id']) && isset($st['api_key']) && '' != trim($st['api_key'])  && isset($st['mode']) && '' != trim($st['mode'])) {
						$id = $st['api_id'];
						$key = $st['api_key'];
						$mode = $st['mode'];
					}
				}

				$id = 'jooviiauspost_api_id';
				$key = 'jooviiauspost_api_key';

				return ['api_id' => $id, 'api_key' => $key, 'mode' => $mode];
			}

			/**
			* This is a copy function synchronised settings with webapp data.
			*
			* @internal
			*
			* @return string
			*/
			public function JooviiAuspost_webapp_sync_store() {
				JooviiAuspost_logActions('Sync Started');
				$all_options = wp_load_alloptions();
				$allopt=maybe_unserialize($all_options['woocommerce_jooviiauspost_settings']);
				$set = $this->JooviiAuspost_get_existing_settings();
				if ( '' != $set['api_id']   ) {
					$set['site_url'] = get_option('siteurl');
					$set['id'] = uniqid();
					$set['name'] = get_option('blogname');
					$set['email'] = get_option('admin_email');
					$set['ecomtype'] = 'woocom_auspost';
					$set['domain'] = ( isset ($_SERVER['REMOTE_ADDR']) ? sanitize_text_field(wp_unslash($_SERVER['REMOTE_ADDR'])) : '' );
					$d = get_option('woocommerce_default_country');
					$province = $d;
					$country  = $d;
					if ( '' != $d) {
						$t = explode(':', $d);
						if (count($t) == 2) {
							$country  = $t[0];
							$province = $t[1];
						}
					}
					$set['province']  = $province;
					$set['country']   = $country;
					$set['address1']  = trim(get_option('woocommerce_store_address'));
					$set['address2']  = trim(get_option('woocommerce_store_address_2'));
					$set['zip']       = get_option('woocommerce_store_postcode');
					$set['city']      = get_option('woocommerce_store_city');
					$set['source']    = '';
					$set['phone']     = '';
					$set['latitude']  = '';
					$set['longitude'] = '';
					$set['primary_locale'] = 'en';
					//$set['created_at']   = '';
					//$set['updated_at']   = '';
					$set['country_code'] = $country;
					$set['country_name'] = get_option('woocommerce_default_country');
					$set['currency']     = get_option('woocommerce_currency');
					$set['customer_email'] = get_option('admin_email');
					$set['timezone'] = '';
					$set['iana_timezone'] = '';
					$set['shop_owner']   = '';
					$admin_user = get_user_by( 'email', $set['email']);

					if ( '' == $allopt['sender_name']) {
						if ( $admin_user ) {
							$first_name = get_user_meta($admin_user->ID, 'first_name', true);
							$last_name  = get_user_meta($admin_user->ID, 'last_name', true);
							if ( '' == $first_name . $last_name) {
								$set['shop_owner'] = get_option('blogname');
							} else {
								$set['shop_owner'] = $first_name . ' ' . $last_name;
							}
						}
					} else {
						$set['shop_owner'] = $allopt['sender_name'];
					}
					$set['money_format'] = $set['currency'] . '{{amount}}';
					$set['money_with_currency_format']='${{amount}} ' . $set['currency'];
					$set['weight_unit'] = get_option('woocommerce_weight_unit');
					$set['dimension_unit'] = get_option('woocommerce_dimension_unit');
					$set['province_code'] = $province;
					$set['taxes_included']='';
					$set['auto_configure_tax_inclusivity']='';
					$set['tax_shipping']='';
					$set['county_taxes'] = '1';
					$set['plan_display_name'] = '';
					$set['plan_name']  = '';
					$set['has_discounts']='';
					$set['has_gift_cards']='';
					$set['myshopify_domain']='';
					$set['google_apps_domain']='';
					$set['google_apps_login_enabled']='';
					$set['money_in_emails_format']= $set['currency'] . '{{amount}}';
					$set['money_with_currency_in_emails_format']='${{amount}} ' . $set['currency'];
					$set['eligible_for_payments'] = '1';
					$set['requires_extra_payments_agreement']='';
					$set['password_enabled']='';
					$set['has_storefront']='';
					$set['finances']='1';
					$set['primary_location_id']='';
					$set['checkout_api_supported']='';
					$set['multi_location_enabled']='';
					$set['setup_required']='';
					$set['pre_launch_enabled']='';
					$set['transactional_sms_disabled']='';
					$set['marketing_sms_consent_enabled_at_checkout']='';
					$set['pickup_country'] = get_option('woocommerce_jooviiauspost_pickup_country');
					// New ADDITION
					//$set['enabled']     = $allopt['enabled'];
					//$set['showrates']   = $allopt['showrates'];
					$set['pickup_suburb'] = $allopt['pickup_suburb'];
					$set['pickup_postcode'] = $allopt['pickup_postcode'];
					$set['pickup_country'] = $allopt['pickup_country'];
					//$set['quote_markup'] = $allopt['quote_markup'];
					//$set['shipping_handling_fee'] = $allopt['shipping_handling_fee'];
					$set['enable_addressmatch'] = $allopt['enable_addressmatch'];
					$set['volume_param'] = isset($allopt['volume_param']) ? $allopt['volume_param'] : '';
					$set['warningtext_enable'] = isset($allopt['warningtext_enable'])?$allopt['warningtext_enable']:'';
					$set['warningtext'] = isset($allopt['warningtext'])?$allopt['warningtext']:'';
					//$set['pickupoption']=$allopt['pickupoption'];
					//$set['book_shipment_on']= $allopt['book_shipment_on'];
					//$set['sender_name']=$allopt['sender_name'];
					$set['sender_contact_number'] = $allopt['sender_contact_number'];
					$set['sender_address'] = trim($set['address1'] . ' ' . $set['address2']);
					$set['sender_state'] = $allopt['sender_state'];
					//$set['sender_instruction']=$allopt['sender_instruction'];
					//$set['receiver_instruction']=$allopt['receiver_instruction'];
					//$set['pickup_delay']=$allopt['pickup_delay'];
					$set['change_order_status'] = $allopt['change_order_status'];
					$set['tracking_email']=$allopt['tracking_email'];
					//$set['hs_code']=$allopt['hs_code'];
					//$set['hs_code_field_name']=$allopt['hs_code_field_name'];
					$set['optintojoovii']=$allopt['optintojoovii'];
					//$set['contents_type']=$allopt['contents_type'];
					$set['enable_log']=$allopt['enable_log'];
					//$set['packaging_weight_cart']=$allopt['packaging_weight_cart'];
					//$set['hide_pickup_address']=$allopt['hide_pickup_address'];
					//$set['customer_reference'] = $allopt['enable_customer_reference'];

					JooviiAuspost_logActions('Before Save-Settings CALL :: ' . print_r($set, true) );
					$ret = JooviiAuspost_makeapicall('/woocom/jooviiauspost/sync/store/savesettings', $set) ;
					JooviiAuspost_logActions('After Save-Settings CALL :: ' . print_r($ret, true) );
					$temp = json_decode($ret, true);
					if ( is_array($temp) ) {
						if ( isset($temp['shop_id']) && '' != $temp['shop_id'] && isset($temp['accesstoken']) && '' != $temp['accesstoken']	) {
							$data = [];
							if ( isset($temp['shop_id']) && '' != $temp['shop_id'] ) {
								$data['shop_id'] = $temp['shop_id'];
							}

							if ( isset($temp['accesstoken']) && '' != $temp['accesstoken'] ) {
								$data['accesstoken'] = $temp['accesstoken'];
							}

							if ( count($data) ) {
								$this->update_JooviiAuspost_settings($data);
							}
						}
						add_action('admin_notices', function() use ( $temp ) {
							if ( is_array($temp) ) {
								if ( isset($temp['err']) && isset($temp['msg']) ) {
									$class = $temp['err'] ? 'error' : 'updated';
									echo '<div class="notice $class"><p>' . esc_html($temp['msg']) . '</p></div>';
								}
							}
						});
					} else {
						add_action('admin_notices', function() use ( $temp ) {
							echo '<div class="notice error"><p>Credential Validation Failed</p></div>';
						} );
					}
				} else {
					JooviiAuspost_logActions('SaveSettings Error .. Params Missing');
				}
			}
			/**
			* This is a copy function also adds setting.
			*
			* @internal
			*
			* @return array
			*/
			public function update_JooviiAuspost_settings($arr) {
				$st = maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
				if ( is_array($st) ) {
					foreach ($arr as $key => $val) {
						if ( '' != $key) {
							if ( 'accesstoken' == $key  ||  'shop_id' == $key ) {
								$st[$key] = $val;
							}
						}
					}
					JooviiAuspost_logActions('Updated shopid and accesstoken in Settings');
					update_option('woocommerce_jooviiauspost_settings', $st);
				}
			}
		}
	}
}

/**
* This function adds a Shipping Method.
*
* @internal
*
* @return array
*/

function JooviiAuspost_add_shipping_method( $methods ) {
	$methods[] = 'JooviiAuspost_Shipping_Method';
	return $methods;
}

/**
* This function is for Logging various Actions.
*
* @internal
*
* @return boolean
*/
function JooviiAuspost_logActions($message) {
	global $wpdb;
	$jooviiAuspost_setting  = 	maybe_unserialize( get_option('woocommerce_jooviiauspost_settings') );
	if ( isset($jooviiAuspost_setting['enable_log']) && 'yes' == $jooviiAuspost_setting['enable_log']) {
		if ( false !== strpos( $message, 'wp_order_id' ) ) {
			$strpos=strpos($message, 'wp_order_id');
			$orderid= (float) trim (substr ($message, $strpos + 15, 4));
		} else {
			$orderid = 0;
		}
		$table_name = $wpdb->prefix . 'jooviiauspost_logs';
		$date = gmdate('Y-m-d H:i:s');
		$wpdb->insert( $table_name, array('eventname'=>'null', 'orderid'=>$orderid, 'logs'=>$message, 'timestamp'=> $date), array('%s', '%d', '%s'));
	}
}

/**
* This function is for making API call.
*
* @internal
*
* @return mixed
*/ 
function JooviiAuspost_makeapicall($uriPath, $postDataArr) {
	$postDataStr = '';
	$base_url = JOOVIIAUSPOST_WEBAPP_URL;
	if ( is_array($postDataArr) && count($postDataArr) ) {
		foreach ($postDataArr as $key=>$val) {
			if ($val) {
				$postDataStr .= "$key=" . rawurlencode(trim($val)) . '&';
			}
		}
		$postDataStr = rtrim($postDataStr, '&');
		$target_url = $base_url . $uriPath;
		$args = ['httpversion' => '1.0','body'=> $postDataStr,'method'=> 'POST',];
		JooviiAuspost_logActions("Posting [$postDataStr] to $target_url");
		$content = wp_remote_post($target_url, $args);
		if ( is_wp_error( $content ) ) {
			$error_message = $content->get_error_message();
			return  'Something went wrong [wp_remote_post]:' . $error_message;
		}
		$response  = wp_remote_retrieve_body( $content );
		return $response;
	} else {
		return ['error' => 1, 'msg' => 'Validation Failed'];
	}
}

/**
* This is a copy function also adds setting.
*
* @internal
*
* @return string
*/

function JooviiAuspost_getAssignRole() {
	$c_id = get_current_user_id();
	$assign_role = '';
	$user = new WP_User($c_id);
	if (isset($user->roles[0])) {
		$u_role =  $user->roles[0];
		if ( 'administrator' == $u_role) {
			$assign_role = $u_role;
		} else {
			$jooviiAuspost_setting = maybe_unserialize(get_option('woocommerce_jooviiauspost_settings'));
			$role_manager_settings = $jooviiAuspost_setting['role_manager'];
			if ($u_role == $role_manager_settings) {
				$assign_role = $u_role;
			}
		}
	}
	return $assign_role;
}

/**
* This function is for getting ASSIGN permission.
*
* @internal
*
* @return String
*/

function JooviiAuspost_getAssignPermission() {
	$c_id = get_current_user_id();
	$assign_permission = '0';
	$user = new WP_User($c_id);
	if (isset($user->roles[0])) {
		$u_role =  $user->roles[0];
		if ( 'administrator' == $u_role) {
			$assign_permission = '1';
		} else {
			$jooviiAuspost_setting = maybe_unserialize(get_option('woocommerce_jooviiauspost_settings'));
			$role_manager_settings = $jooviiAuspost_setting['role_manager'];
			if ($u_role == $role_manager_settings) {
				$assign_permission = '1';
			}
		}
	}
	return $assign_permission;
}


add_action('upgrader_process_complete', 'JooviiAuspost_plugin_upgrade_completed', 10, 2);

function JooviiAuspost_plugin_upgrade_completed($upgrader_object, $hook_extra)
{

	// get current plugin version. ( https://wordpress.stackexchange.com/a/18270/41315 )
    if(!function_exists('get_plugin_data')){
        require_once(ABSPATH . 'wp-admin/includes/plugin.php');
    }
    // https://developer.wordpress.org/reference/functions/get_plugin_data/
    $plugin_data = get_plugin_data(__FILE__);
    $plugin_version = ($plugin_data['Version'] ?? 'unknown.version');
    unset($plugin_data);

	JooviiAuspost_logActions('INSIDE UPGRADE COMPLETE HOOK : STEP 1' );

	if ( is_array($hook_extra) && array_key_exists('action', $hook_extra) && $hook_extra['action'] == 'update') {
		if (array_key_exists('type', $hook_extra) && $hook_extra['type'] == 'plugin') {
			JooviiAuspost_logActions('INSIDE UPGRADE COMPLETE HOOK : STEP 2' );
			// if updated the plugins.
            $this_plugin = plugin_basename(__FILE__);
			$this_plugin_updated = false;
			if (array_key_exists('plugins', $hook_extra)) {
				// if bulk plugin update (in update page)
				foreach ($hook_extra['plugins'] as $each_plugin) {
					if ($each_plugin === $this_plugin) {
						$this_plugin_updated = true;
						break;
					}
				}// endforeach;
				unset($each_plugin);
			} elseif (array_key_exists('plugin', $hook_extra)) {
				// if normal plugin update or via auto update.
				if ($this_plugin === $hook_extra['plugin']) {
					$this_plugin_updated = true;
				}
			}

			if ($this_plugin_updated === true) {
				// if this plugin is just updated.
				JooviiAuspost_logActions('INSIDE UPGRADE COMPLETE HOOK : STEP 3' );
				// NOW CALL API to send SETTINGS
				if ( ! class_exists( 'JooviiAuspost_Shipping_Method' ) )
				{
					JooviiAuspost_Shipping_Method();
					$JooviiAuspost_obj = new JooviiAuspost_Shipping_Method;
					$JooviiAuspost_obj->JooviiAuspost_webapp_sync_store();
				    JooviiAuspost_logActions('INSIDE UPGRADE COMPLETE HOOK : SYNC Phase Success' );
				}

				// set transient to let it run later.
				// set_transient('JooviiAuspost_joovii_plugin_just_updated', 1);
			} else {
				JooviiAuspost_logActions('INSIDE UPGRADE COMPLETE HOOK : STEP 4' );
			}
		}
	}// endif; $hook_extra

	JooviiAuspost_logActions('INSIDE UPGRADE COMPLETE HOOK : STEP 5' );
}


